%define anolis_release 1
%bcond_with check

%global srcname astropy

Name: python-%{srcname}
Version: 5.3.2
Release: %{anolis_release}%{?dist}
Summary: A Community Python Library for Astronomy
License: BSD-3-Clause AND CFITSIO

URL: http://astropy.org
Source0: %{pypi_source}
Source1: astropy-README.dist
Patch0: python-astropy-system-configobj.patch
Patch1: python-astropy-system-ply.patch

%global _description %{expand:
The Astropy project is a common effort to develop a single core package
for Astronomy. Major packages such as PyFITS, PyWCS, vo, and asciitable
already merged in, and many more components being worked on. In
particular, we are developing imaging, photometric, and spectroscopic
functionality, as well as frameworks for cosmology, unit handling, and
coordinate transformations.}

%description %_description

%package -n python3-%{srcname}
Summary: %{summary}
BuildRequires: gcc
BuildRequires: python3-devel
BuildRequires: expat-devel >= 2.2.9
BuildRequires: %{py3_dist setuptools}
BuildRequires: %{py3_dist setuptools_scm}
BuildRequires: %{py3_dist Cython}
BuildRequires: %{py3_dist jinja2}
BuildRequires: %{py3_dist numpy}
BuildRequires: %{py3_dist extension-helpers}
BuildRequires: %{py3_dist configobj}
BuildRequires: %{py3_dist ply}
BuildRequires: %{py3_dist pyyaml}
BuildRequires: %{py3_dist packaging}
%if %{with check}
BuildRequires: %{py3_dist pytest}
BuildRequires: %{py3_dist hypothesis}
BuildRequires: %{py3_dist pyerfa}
BuildRequires: %{py3_dist pytest-remotedata}
BuildRequires: %{py3_dist pytest-mpl}
BuildRequires: %{py3_dist pytest-astropy}
#
BuildRequires: %{py3_dist scipy}
BuildRequires: %{py3_dist matplotlib}
BuildRequires: %{py3_dist pandas}
BuildRequires: %{py3_dist h5py}
BuildRequires: %{py3_dist scikit-image}
%endif

Requires: %{py3_dist configobj}
Requires: %{py3_dist ply}
Provides: bundled(jquery) = 3.11

%description -n python3-%{srcname} %_description

%package -n python3-%{srcname}-doc
Summary: Documentation for %{name}, includes full API docs

%description -n python3-%{srcname}-doc
This package contains the full API documentation for %{name}.

%package -n %{srcname}-tools
Summary: Astropy utility tools
BuildArch: noarch
Requires: python3-%{srcname} = %{version}-%{release}

%description -n %{srcname}-tools
Utilities provided by Astropy.

%prep
%autosetup -n %{srcname}-%{version} -p1

%build
# Search for headers in subdirs
%{py3_build}

%install
# Search for headers in subdirs
%{py3_install}

%if %{with check}
%check
export PYTEST_ADDOPTS='-p no:cacheprovider'
# https://github.com/astropy/astropy/issues/15238
pytest_args=(
%ifarch aarch64
 --deselect "astropy/modeling/tests/test_quantities_fitting.py::test_fitting_with_initial_values[DogBoxLSQFitter]"
 --deselect astropy/wcs/tests/test_tabprm.py::test_tabprm_print
%endif
 --deselect astropy/io/votable/tests/vo_test.py::test_gzip_filehandles
 --deselect astropy/nddata/mixins/tests/test_ndslicing.py::test_slicing_all_something_wrong
 --deselect astropy/table/tests/test_table.py::test_table_attribute_fail
)

cp conftest.py %{buildroot}/%{python3_sitearch}
pushd %{buildroot}/%{python3_sitearch}
  %{pytest} "${pytest_args[@]}"  --hypothesis-profile="ci" 
  # remove hypothesis dir
  rm -rf .hypothesis
  rm conftest.py
popd
%endif

%files -n %{srcname}-tools
%{_bindir}/*

%files -n python3-%{srcname}
%doc README.rst
%license LICENSE.rst
%{python3_sitearch}/%{srcname}/
%{python3_sitearch}/%{srcname}-*.egg-info

%files -n python3-%{srcname}-doc
%doc README.rst 
%license LICENSE.rst cextern/cfitsio/License.txt

%changelog
* Mon Feb 19 2024 zhongling.h <zhonglingh@linux.alibaba.com> - 5.3.2-1
- Initial package.